Overview
--------

The Ralph Assets module brings offline stock management functionality to Ralph.
It maintains placing orders, purchasing and releasing of devices to the users.
It is not limited to the data center. You can maintain inventory of your back
office assets with it as well.

Ralph is an asset management system for your data center. It lets you see what
hardware and software is installed. It also lets you keep track of who is using
every device, for what, and how much it costs.

This documentation
------------------

See: quickstart.rst and installation.rst

.. toctree::
   :maxdepth: 2

   quickstart
   installation
   transitions


